@@ -26,11 +26,11 @@ C3000 - A perl wrap for C3000 API
 
 =head1 VERSION
 
-Version 0.01
+Version 1.02
 
 =cut
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 =head1 SYNOPSIS
  
@@ -43,9 +43,40 @@ our $VERSION = '1.01';
 
 =head1 Methods 
 
-=head2 new
+    get_LP
+    save_LP
+    accu_value
+    accu_tariff_value
+    get_variable_name
+    get_single_value
+    get_range_value
+    get_last_time
+    get_period
+    get_BV
+    search_device
+    search_ADAS_node
+    search_group
+    set_ADAS_node
+    del_paths
+    del_meters
+    del_VMs
+    create_path
+    get_tariff
+    get_tariff_id
+    eval_AMD
+    convert_VT_DATE
+    CreateMasterAccount
+    GetContainerID
+    GetDataSegmentID
+    GetTemplateID
+    exec_jobs
+    search_AE
+    search_CT
+    search_AETempl
+    search_CTTempl
+    search_meter_by_proxyattr
+    search_meter_by_AMD
 
-init sub
 
 =cut
 
